@@ -24,7 +24,7 @@
 #ifndef KUISERVERJOBTRACKER_P_H
 #define KUISERVERJOBTRACKER_P_H
 
-#include <QtCore/QMap>
+#include <QDBusServiceWatcher>
 
 #include "jobviewserverinterface.h"
 
@@ -38,8 +38,15 @@ public:
 
     org::kde::JobViewServer &uiserver();
 
+Q_SIGNALS:
+    void serverRegistered();
+    void serverUnregistered();
+
 private:
+    void uiserverOwnerChanged(const QString &serviceName, const QString &oldOwner, const QString &newOwner);
+
     org::kde::JobViewServer m_uiserver;
+    QDBusServiceWatcher m_watcher;
 };
 
 #endif
